aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/roff.c
diff options
context:
space:
mode:
Diffstat (limited to 'roff.c')
-rw-r--r--roff.c11
1 files changed, 5 insertions, 6 deletions
diff --git a/roff.c b/roff.c
index e4c973ba..d40c4b35 100644
--- a/roff.c
+++ b/roff.c
@@ -1,4 +1,4 @@
-/* $Id: roff.c,v 1.56 2008/12/09 19:57:26 kristaps Exp $ */
+/* $Id: roff.c,v 1.57 2008/12/10 00:52:46 kristaps Exp $ */
/*
* Copyright (c) 2008 Kristaps Dzonsons <kristaps@kth.se>
*
@@ -938,11 +938,11 @@ roff_Dd(ROFFCALL_ARGS)
/*
* This is a bit complex because there are many forms the date
* can be in: it can be simply $Mdocdate: December 9 2008 $, $Mdocdate <date>$,
* or a raw date. Process accordingly.
*/
- if (0 == strcmp(*argv, "$Mdocdate: December 9 2008 $")) {
+ if (0 == strcmp(*argv, "$Mdocdate: December 10 2008 $")) {
t = time(NULL);
if (NULL == localtime_r(&t, &tree->tm))
err(1, "localtime_r");
@@ -1154,7 +1154,7 @@ static int
roff_layout(ROFFCALL_ARGS)
{
int i, c, argcp[ROFF_MAXLINEARG];
- char *argvp[ROFF_MAXLINEARG], *p;
+ char *argvp[ROFF_MAXLINEARG];
/*
* The roff_layout function is for multi-line macros. A layout
@@ -1180,10 +1180,9 @@ roff_layout(ROFFCALL_ARGS)
return((*tree->cb.roffblkout)(tree->arg, tok));
}
+ argv++;
assert( ! (ROFF_CALLABLE & tokens[tok].flags));
- p = *argv++;
-
if ( ! roffparseopts(tree, tok, &argv, argcp, argvp))
return(0);
if (NULL == roffnode_new(tok, tree))
@@ -938,11 +938,11 @@ roff_Dd(ROFFCALL_ARGS)
/*
* This is a bit complex because there are many forms the date
- * can be in: it can be simply $Mdocdate: December 9 2008 $, $Mdocdate <date>$,
+ * can be in: it can be simply $Mdocdate: December 10 2008 $, $Mdocdate <date>$,
* or a raw date. Process accordingly.
*/